@@ -5,6 +5,8 @@
 # Should be executed with a cron job.
 #
 #---------------------------------------------#
+from django.utils.encoding import python_2_unicode_compatible
+from django.utils.translation import ugettext_lazy as _
 import datetime
 import logging
 import os
@@ -28,21 +30,37 @@ class MailerMessageManager(models.Manager):
         for email in self.filter(sent=False)[:limit]:
             email.send()
 
+    def clear_sent_messages(self, offset=None):
+        """ Deletes sent MailerMessage records """
+        if offset is None:
+            offset = getattr(settings, 'MAILQUEUE_CLEAR_OFFSET', defaults.MAILQUEUE_CLEAR_OFFSET)
 
+        if type(offset) is int:
+            offset = datetime.timedelta(hours=offset)
+
+        delete_before = datetime.datetime.utcnow().replace(tzinfo=utc) - offset
+        self.filter(sent=True, last_attempt__lte=delete_before).delete()
+
+
+@python_2_unicode_compatible
 class MailerMessage(models.Model):
-    subject = models.CharField(max_length=250, blank=True)
-    to_address = models.EmailField(max_length=250)
-    bcc_address = models.EmailField(max_length=250, blank=True)
-    from_address = models.EmailField(max_length=250)
-    content = models.TextField(blank=True)
-    html_content = models.TextField(blank=True)
-    app = models.CharField(max_length=250, blank=True)
-    sent = models.BooleanField(default=False, editable=False)
-    last_attempt = models.DateTimeField(auto_now=False, auto_now_add=False, blank=True, null=True, editable=False)
+    subject = models.CharField(_('Subject'), max_length=250, blank=True)
+    to_address = models.EmailField(_('To'), max_length=250)
+    bcc_address = models.EmailField(_('BCC'), max_length=250, blank=True)
+    from_address = models.EmailField(_('From'), max_length=250)
+    content = models.TextField(_('Content'), blank=True)
+    html_content = models.TextField(_('HTML Content'), blank=True)
+    app = models.CharField(_('App'), max_length=250, blank=True)
+    sent = models.BooleanField(_('Sent'), default=False, editable=False)
+    last_attempt = models.DateTimeField(_('Last attempt'), auto_now=False, auto_now_add=False, blank=True, null=True, editable=False)
 
     objects = MailerMessageManager()
 
-    def __unicode__(self):
+    class Meta:
+        verbose_name = _('Message')
+        verbose_name_plural = _('Messages')
+
+    def __str__(self):
         return self.subject
 
     def add_attachment(self, attachment):
@@ -62,7 +80,18 @@ class MailerMessage(models.Model):
         self.do_not_send = True
         super(MailerMessage, self).save(*args, **kwargs)
 
-    def send(self):
+    def send_mail(self):
+        """ Public api to send mail.  Makes the determinination
+         of using celery or not and then calls the appropriate methods.
+        """
+
+        if getattr(settings, 'MAILQUEUE_CELERY', defaults.MAILQUEUE_CELERY):
+            from mailqueue import tasks
+            tasks.send_mail(self.pk)
+        else:
+            self._send()
+
+    def _send(self):
         if not self.sent:
             if getattr(settings, 'USE_TZ', False):
                 # This change breaks SQLite usage.
@@ -89,18 +118,22 @@ class MailerMessage(models.Model):
             try:
                 msg.send()
                 self.sent = True
-            except Exception, e:
+            except Exception as e:
                 self.do_not_send = True
                 logger.error('Mail Queue Exception: {0}'.format(e))
-
             self.save()
 
 
+@python_2_unicode_compatible
 class Attachment(models.Model):
     file_attachment = models.FileField(upload_to='mail-queue/attachments', blank=True, null=True)
     email = models.ForeignKey(MailerMessage, blank=True, null=True)
 
-    def __unicode__(self):
+    class Meta:
+        verbose_name = _('Attachment')
+        verbose_name_plural = _('Attachments')
+
+    def __str__(self):
         return self.file_attachment.name
 
 @receiver(post_save, sender=MailerMessage)
@@ -109,8 +142,7 @@ def send_post_save(sender, instance, signal, *args, **kwargs):
         instance.do_not_send = False
         return
 
-    if getattr(settings, 'MAILQUEUE_CELERY', defaults.MAILQUEUE_CELERY):
-        from mailqueue.tasks import send_mail
-        send_mail.delay(instance.pk)
-    else:
-        instance.send()
+    if not getattr(settings, 'MAILQUEUE_QUEUE_UP', defaults.MAILQUEUE_QUEUE_UP):
+        # If mail queue up is set, wait for the cron or management command
+        # to send any email.
+        instance.send_mail()
